package com.hikcreate.edl.pub.web.mobile.api.controller;

import com.hikcreate.common.sdk.response.apiparam.Response;
import com.hikcreate.common.sdk.response.apiparam.ResponseGenerator;
import com.hikcreate.common.sdk.response.statuscode.StatusCode;
import com.hikcreate.edl.pub.web.mobile.domain.IBindService;
import com.hikcreate.edl.pub.web.mobile.infra.core.Result;
import com.hikcreate.edl.pub.web.mobile.infra.core.enums.ResultCode;
import com.hikcreate.edl.pub.web.mobile.infra.model.BindInfoQuery;
import com.hikcreate.edl.pub.web.mobile.infra.model.param.response.DrivingLicenseInfoRes;
import com.hikcreate.edl.pub.web.mobile.infra.model.param.response.InsuranceInfoRes;
import com.hikcreate.edl.pub.web.mobile.infra.model.param.response.ResultList;
import com.hikcreate.edl.pub.web.mobile.infra.model.param.response.ViolationInfoRes;
import com.hikcreate.edl.pub.web.mobile.infra.model.param.response.YearCheckInfoRes;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * 对外提供给H5的接口
 * @menu H5接口
 * @author: xieshixiang
 * @time：2020/6/19 16:37
 **/
@RestController
@RequestMapping("/vehicle")
@Slf4j
public class H5Controller {

    @Autowired
    IBindService service;

    /**
     * 年检信息查询接口
     *
     * @param query
     * @return Result
     * @author: xsx
     * @date: 2020/6/19 10:32
     */
    @GetMapping("yearCheckInfo")
    public Response<YearCheckInfoRes> yearCheckInfo( @RequestBody @Validated BindInfoQuery query) {
        if (query == null) {
            return ResponseGenerator.fail(StatusCode.PARAM_ERROR);
        }
        return service.yearCheckInfo(query);
    }

    /**
     * 违法信息查询接口
     *
     * @param query
     * @return Result
     * @author: xsx
     * @date: 2020/6/19 16:28
     */
    @GetMapping("violationInfo")
    public Response<ResultList<ViolationInfoRes>> violationInfo(@RequestBody @Validated BindInfoQuery query) {
        if (query == null) {
            return ResponseGenerator.fail(StatusCode.PARAM_ERROR);
        }
        return service.violationInfo(query);
    }

    /**
     * 保险信息查询接口
     *
     * @param query
     * @return Result
     * @author: xsx
     * @date: 2020/6/19 16:28
     */
    @GetMapping("insuranceInfo")
    public Response<InsuranceInfoRes> insuranceInfo(@RequestBody @Validated BindInfoQuery query) {
        if (query == null) {
            return ResponseGenerator.fail(StatusCode.PARAM_ERROR);
        }
        return service.insuranceInfo(query);
    }

    /**
     * 驾照信息查询接口
     *
     * @param query
     * @return Result
     * @author: xsx
     * @date: 2020/6/19 16:28
     */
    @GetMapping("drivingLicenseInfo")
    public Response<DrivingLicenseInfoRes> drivingLicenseInfo(@RequestBody BindInfoQuery query) {
        if (query == null) {
            return ResponseGenerator.fail(StatusCode.PARAM_ERROR);
        }
        return service.drivingLicenseInfo(query);
    }
}
